import { OnInit, EventEmitter, ElementRef, QueryList } from '@angular/core';
import { PagerComponent } from 'cl-angular-pager';
import { SearchCriteria } from 'cl-angular-core';
import { ComboboxSettings, ComboboxStyles } from 'cl-angular-combobox';
import { Column, FilterItem, Action } from './data-table.bundle';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';
import { DataTableFilterComponent } from './filter/data-table-filter.component';
import { DataTableStorageModel } from './models/data-table-storage';
export declare class DataTableComponent/*extends BaseComponent*/  implements OnInit {
    dialog: MatDialog;
    router: Router;
    route: ActivatedRoute;
    postInProgress: boolean;
    identifier: string;
    commentsEnabled: boolean;
    documentsEnabled: boolean;
    uiSelectionEnabled: boolean;
    baseURL: string;
    dataTableFilters: QueryList<DataTableFilterComponent>;
    pager: PagerComponent;
    tableContainer: ElementRef;
    actionsContainer: ElementRef;
    emptyResultPagerTemplate: string;
    emptyResultTemplateShownInPager: boolean;
    searchTerm: string;
    loading: boolean;
    enabled: boolean;
    columnFilterEnabled: boolean;
    hasFilters: boolean;
    items: any[];
    columns: Column[];
    actionColumn: Column;
    columnActions: Action[];
    pageCount: number;
    pageIndex: number;
    itemCount: number;
    context: any;
    configPath: string;
    configurationLoaded: boolean;
    private _dataTableID;
    get dataTableID(): number;
    set dataTableID(v: number);
    onConfigurationLoaded: EventEmitter<any>;
    onFilterUpdated: EventEmitter<any>;
    onSortPreferenceChanged: EventEmitter<any>;
    onGroupPreferenceChanged: EventEmitter<any>;
    onPageChanged: EventEmitter<any>;
    onPageCountChanged: EventEmitter<any>;
    onUserDefinedFilterSelected: EventEmitter<any>;
    onInsertFormRequested: EventEmitter<any>;
    onEntitySelected: EventEmitter<any>;
    onRowSelected: EventEmitter<any>;
    onColumnSelected: EventEmitter<any>;
    onSelectionChanged: EventEmitter<any>;
    placeboRowHeight: number;
    selectedAction: number;
    isFullScreen: boolean;
    isScrollable: boolean;
    isCompressed: boolean;
    containsNestedData: boolean;
    computeProperyForItem: Function;
    activeColumns: Column[];
    isAdmin: boolean;
    dataTableStorage: DataTableStorageModel;
    userDefinedFilter: UserDefinedFilterModel;
    comboboxSettings: ComboboxSettings;
    comboboxStyles: ComboboxStyles;
    filterManagementPageMode: FilterManagementPageMode;
    constructor(dialog: MatDialog, router: Router, route: ActivatedRoute);
    ngOnInit(): void;
    setComboboxSettings(): void;
    setDataTableSettings(dataTableSetting: DataTableStorageModel, triggerOnFilterUpdated?: boolean): void;
    clearFilters(): void;
    pageChanged($event: any): void;
    pageCountChanged($event: any): void;
    actionTriggered(action: Action, item: any): void;
    tableConfig: any;
    loadConfig(loader: any): void;
    applyConfig(tableConfig: any): void;
    activateColumns(): void;
    getAllItems(): any[];
    confirm(): void;
    decline(): void;
    setItems(items: any, itemCount: any, pageNumber: any, userDefinedFilters?: any, predefinedFilter?: any): void;
    renderItems(items?: any[]): void;
    activeContextItem: any;
    createContextMenu(): void;
    setActiveColumns(): void;
    saveDataTableColumns(): void;
    getDivisionColumns(): Column[];
    setFilter(filter: string, items: FilterItem[], operator?: string): void;
    searchInputChanged(): void;
    generalSearchInputChanged($event: any): void;
    filters: SearchCriteria[];
    onFilterChanged(): void;
    changeFilterState(): void;
    sort(column: Column): void;
    group(column: Column): void;
    extractDivisionValue(item: any, column: Column, index: number): any;
    extractValue(item: any, column: Column): any;
    extractRawValue(item: any, field: string, separator?: string, returnLength?: boolean): any;
    presentInsertForm(): void;
    getDeletedCondition(item: any, rowIndex: any): {
        'text-decoration': string;
        'background-color': string;
    } | {
        'background-color': string;
        'text-decoration'?: undefined;
    };
    clickedOutside($event: any): void;
    onWindowScroll(event: any): void;
    onScroll(event: MouseEvent): void;
    onMouseWheel(event: WheelEvent): void;
    toggleActionsDropdown(event: any, item: any): void;
    closeContextMenu(): void;
    exportPDF(): void;
    exportExcel(): void;
    prepareItems(items: any): void;
    exportItemsToExcel(items: any[]): void;
    toggleScroll(): void;
    toggleCompactMode(): void;
    toggleSize(event: any): void;
    rowSelectionEnabled: boolean;
    itemClicked(item: any): void;
    getSelectedItems(): any[];
    itemSelectionChanged: boolean;
    checkedChanged(item: any): void;
    allSelected: boolean;
    toggleAllSelection(): void;
    onRightClick($event: any, item: any): boolean;
    optionsMenuVisible: boolean;
    toggleOptionsMenu(): void;
    closeOptionsMenu(): void;
    shiftColumn(column: Column, shift: number): void;
    activeColumnConfigChanged(): void;
    activeRow: number;
    activeColumn: number;
    columnCount: number;
    rowCount: number;
    activeItem: any;
    columnSelected(row: number, column: number, item: any): boolean;
    rowSelected(row: number): boolean;
    rowToBeSelected: number;
    columnToBeSelected: number;
    keyboardInput($event: any): void;
    gcd(a: any, b: any): any;
    lcm(a: any, b: any): number;
    range_lcm(arr: any): any;
    setPredefinedFilter(filter: string): void;
    turnDefaultFilterActionClicked(): void;
    activeUserDefinedFilter: any;
    editUserDefinedFilterActionClicked(userDefinedFilter: FilterItem): void;
    addNewFilterButtonClicked(): void;
    cancelUserDefinedFilterActionClicked(userDefinedFilter: FilterItem): void;
    activateActionClicked(userDefinedFilter: FilterItem): void;
    userDefinedFilters: FilterItem[];
    setUserDefinedFilters(filters: UserDefinedFilterModel[]): void;
    selectedUserDefinedFilterChange(event: FilterItem[]): void;
    editTable(): void;
    tableSettingMode: TableSettingMode;
    openFilterPopup(userDefinedFilterPopupTemplate: any): void;
    switchTableSettingMode(): void;
    deleteUserDefinedFilterActionClicked(userDefinedFilter: FilterItem): void;
    saveUserDefinedFilter(): void;
    saveTableSettings(): void;
    getUserDefinedFilters(): void;
    showCommentsButtonClicked(item: any): void;
    showDocumentsButtonClicked(item: any): void;
}
export declare enum TableSettingMode {
    Default = 1,
    FilterManagement = 2
}
export declare enum FilterManagementPageMode {
    List = 0,
    Insert = 1,
    Update = 2
}
export declare class UserDefinedFilterModel {
    id: number;
    displayIndex: number;
    userID: number;
    dataTableID: number;
    name: string;
    filterJson: string;
    user: any;
    updaterEntity: any;
    creatorEntity: any;
}
